pitchtools.respell_named_chromatic_pitches_in_expr_with_sharps
==============================================================

.. autofunction:: abjad.tools.pitchtools.respell_named_chromatic_pitches_in_expr_with_sharps.respell_named_chromatic_pitches_in_expr_with_sharps
